"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.burnJobRenderV0Ix = exports.createJobV0Ix = exports.transferToAccountEscrowIx = exports.initializeUserV0Ix = exports.addTreeV0Ix = exports.initializeMakerV0Ix = void 0;
const anchor_1 = require("@coral-xyz/anchor");
const spl_token_1 = require("@solana/spl-token");
const spl_utils_1 = require("@render-foundation/spl-utils");
const constants_1 = require("./constants");
const pdas_1 = require("./pdas");
const aws_sdk_1 = __importDefault(require("aws-sdk"));
const initializeMakerV0Ix = (program, args, accts) => {
    var _a, _b;
    const maker = (0, pdas_1.makerKey)(args.name)[0];
    const collection = (0, pdas_1.collectionKey)(maker)[0];
    return (program.methods
        .initializeMakerV0({
        updateAuthority: args.updateAuthority,
        issuingAuthority: (_a = args.issuingAuthority) !== null && _a !== void 0 ? _a : args.updateAuthority,
        name: args.name,
        symbol: args.symbol,
        metadataUri: args.metadataUri,
    })
        .accounts({
        payer: (_b = accts.payer) !== null && _b !== void 0 ? _b : args.updateAuthority,
        maker,
        collection,
    })
        .instruction());
};
exports.initializeMakerV0Ix = initializeMakerV0Ix;
const addTreeV0Ix = (program, args, accts) => {
    var _a;
    const maker = (0, pdas_1.makerKey)(args.makerName)[0];
    const treeConfig = (0, pdas_1.treeConfigKey)(accts.merkleTree)[0];
    return program.methods
        .addTreeV0({
        maxDepth: args.maxDepth,
        maxBufferSize: args.maxBufferSize,
    })
        .accounts({
        updateAuthority: accts.updateAuthority,
        payer: (_a = accts.payer) !== null && _a !== void 0 ? _a : accts.updateAuthority,
        maker,
        merkleTree: accts.merkleTree,
        treeConfig,
    })
        .instruction();
};
exports.addTreeV0Ix = addTreeV0Ix;
const initializeUserV0Ix = (program, { accountId, }, { renderMint, authority, payer, }) => {
    return program.methods
        .initializeUserV0({ accountId })
        .accounts({
        authority,
        payer: payer !== null && payer !== void 0 ? payer : authority,
        userAccount: (0, pdas_1.userAccountKey)(accountId)[0],
        accountEscrow: (0, pdas_1.accountEscrowKey)(accountId, renderMint)[0],
        renderMint: renderMint !== null && renderMint !== void 0 ? renderMint : constants_1.RENDER_MINT,
    })
        .instruction();
};
exports.initializeUserV0Ix = initializeUserV0Ix;
const transferToAccountEscrowIx = (conn, { userId, amount, fromAta, from, mint = constants_1.RENDER_MINT, decimals = 8, }) => __awaiter(void 0, void 0, void 0, function* () {
    const ata = yield (0, spl_utils_1.isAta)(conn, fromAta);
    if (!ata) {
        throw new Error(`from ${fromAta} is not an ata`);
    }
    return (0, spl_token_1.createTransferCheckedInstruction)(fromAta, mint, (0, pdas_1.accountEscrowKey)(userId, mint)[0], ata.owner, amount, decimals);
});
exports.transferToAccountEscrowIx = transferToAccountEscrowIx;
const createJobV0Ix = (program, { accountId, makerName, job, }, accts) => __awaiter(void 0, void 0, void 0, function* () {
    var _a;
    let uri = job.uri;
    if (typeof uri === 'object') {
        // @ts-ignore
        const { accessKey, secretKey, data } = job.uri;
        const bucket = 'render-artist-jobs';
        const s3 = new aws_sdk_1.default.S3({
            accessKeyId: accessKey,
            secretAccessKey: secretKey,
        });
        const params = {
            Bucket: bucket,
            Key: `${job.id}.json`,
            Body: JSON.stringify(data),
            ContentType: 'application/json',
        };
        yield s3.putObject(params).promise();
        uri = `https://${bucket}.s3.us-east-1.amazonaws.com/${job.id}.json`;
        console.log(`upload ${job.id} to ${uri}`);
    }
    const maker = (0, pdas_1.makerKey)(makerName)[0];
    const collection = (0, pdas_1.collectionKey)(maker)[0];
    const treeConfig = (0, pdas_1.treeConfigKey)(accts.merkleTree)[0];
    return program.methods
        .createJobV0({
        jobId: job.id,
        uri: uri,
        accountId,
    })
        .accounts({
        issuingAuthority: accts.issuingAuthority,
        payer: (_a = accts.payer) !== null && _a !== void 0 ? _a : accts.issuingAuthority,
        maker,
        merkleTree: accts.merkleTree,
        collection,
        treeConfig,
        //bubblegumSigner: accts.issuingAuthority
    })
        .instruction();
});
exports.createJobV0Ix = createJobV0Ix;
const burnJobRenderV0Ix = (program, { accountId, jobs, }, accts) => {
    return program.methods
        .burnJobRenderV0({
        accountId,
        jobs: jobs.map((job) => ({
            id: job.id,
            renderSpent: new anchor_1.BN(job.renderSpent),
            completedAt: new anchor_1.BN(Math.trunc(job.completedAt.getTime() / 1000)),
        })),
    })
        .accounts({
        authority: accts.authority,
        renderMint: accts.renderMint,
    })
        .instruction();
};
exports.burnJobRenderV0Ix = burnJobRenderV0Ix;
//# sourceMappingURL=instructions.js.map