"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.userAccountKey = exports.accountEscrowKey = exports.treeConfigKey = exports.collectionKey = exports.collectionMetadataKey = exports.collectionMasterEditionKey = exports.makerKey = void 0;
const web3_js_1 = require("@solana/web3.js");
const constants_1 = require("./constants");
function makerKey(name, programId = constants_1.PROGRAM_ID) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        Buffer.from("maker", "utf-8"),
        Buffer.from(name, "utf-8"),
    ], programId);
}
exports.makerKey = makerKey;
function collectionMasterEditionKey(collection, tokenMetadataProgram = constants_1.MPL_TOKEN_METADATA_PROGRAM_ID) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        Buffer.from("metadata", "utf-8"),
        tokenMetadataProgram.toBuffer(),
        collection.toBuffer(),
        Buffer.from("edition", "utf-8"),
    ], tokenMetadataProgram);
}
exports.collectionMasterEditionKey = collectionMasterEditionKey;
function collectionMetadataKey(collection, tokenMetadataProgram = constants_1.MPL_TOKEN_METADATA_PROGRAM_ID) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        Buffer.from("metadata", "utf-8"),
        tokenMetadataProgram.toBuffer(),
        collection.toBuffer(),
    ], tokenMetadataProgram);
}
exports.collectionMetadataKey = collectionMetadataKey;
function collectionKey(maker, programId = constants_1.PROGRAM_ID) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        Buffer.from("collection", "utf-8"),
        maker.toBuffer(),
    ], programId);
}
exports.collectionKey = collectionKey;
function treeConfigKey(merkleTree, programId = new web3_js_1.PublicKey('BGUMAp9Gq7iTEuizy4pqaxsTyUCBK68MDfK752saRPUY')) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        merkleTree.toBuffer()
    ], programId);
}
exports.treeConfigKey = treeConfigKey;
function accountEscrowKey(uuid, renderMint = constants_1.RENDER_MINT, programId = constants_1.PROGRAM_ID) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        Buffer.from("job_spend_escrow", "utf-8"),
        Buffer.from(uuid.replace(/-/g, ""), "hex"),
        renderMint.toBuffer()
    ], programId);
}
exports.accountEscrowKey = accountEscrowKey;
function userAccountKey(uuid, programId = constants_1.PROGRAM_ID) {
    return web3_js_1.PublicKey.findProgramAddressSync([
        Buffer.from("user_account", "utf-8"),
        Buffer.from(uuid.replace(/-/g, ""), "hex")
    ], programId);
}
exports.userAccountKey = userAccountKey;
//# sourceMappingURL=pdas.js.map