import { ataResolver, combineResolvers, get, renderCommonResolver, resolveIndividual, } from '@render-foundation/spl-utils';
import { PROGRAM_ID, MPL_BUBBLEGUM_PROGRAM_ID } from './constants';
import { PublicKey } from '@solana/web3.js';
import { collectionMetadataKey, collectionMasterEditionKey, accountEscrowKey, userAccountKey, } from './pdas';
export const renderEntityManagerProgramResolver = resolveIndividual(async ({ path }) => {
    if (path[path.length - 1] === 'renderEntityManagerProgram') {
        return PROGRAM_ID;
    }
});
export const renderEntityManagerResolvers = combineResolvers(renderCommonResolver, renderEntityManagerProgramResolver, ataResolver({
    instruction: 'initializeMakerV0',
    account: 'associatedTokenAccount',
    mint: 'collection',
    owner: 'maker',
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'accountEscrow') {
        //const userAccount = get(accounts, [...path.slice(0, path.length - 1)], "userAccount") as PublicKey;
        const renderMint = get(accounts, [
            ...path.slice(0, path.length - 1),
            'renderMint',
        ]);
        return accountEscrowKey(args[0].accountId, renderMint)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'userAccount') {
        return userAccountKey(args[0].accountId)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'collectionMetadata') {
        const collectionK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'collection',
        ]);
        return collectionMetadataKey(collectionK)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'collectionMasterEdition') {
        const collectionK = get(accounts, [
            ...path.slice(0, path.length - 1),
            'collection',
        ]);
        return collectionMasterEditionKey(collectionK)[0];
    }
}), resolveIndividual(async ({ path, accounts, idlIx, provider, args }) => {
    if (path[path.length - 1] === 'bubblegumSigner') {
        return PublicKey.findProgramAddressSync([Buffer.from('collection_cpi', 'utf8')], MPL_BUBBLEGUM_PROGRAM_ID)[0];
    }
}));
//# sourceMappingURL=resolvers.js.map